.. _performance:

Performance Metrics
===================

The Performance Metrics tabs offers a set of metrics that try to measure the efficiency of the simulation performed, and other aspects of it.

.. figure:: fig/fig_performance_1.jpg
   :name: experiment_performance
   :width: 100%
   :align: center
   :alt: Performance Metrics 1

   Performance Metrics Tab

On the left you have the values of the main performance metrics that apply to the experiment. Then, on the right, you see the list of jobs considered for this calculation with their data, also, ``SYPD`` and ``ASYPD`` are calculated individually for these jobs. This list is scrollable.

You can also access a ``Show warnings`` button that opens a list of important information that might affect the calculation of the metrics. You can click again on this button to close the list.

Further information about the metrics is included in the tab.